/* -*- mode: c -*- */
/*
 * Copyright 2005-2006  Francesco Nidito <nids@di.unipi.it>
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation.
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 * Except as contained in this notice, the name of the author shall not be used 
 * in advertising or otherwise to promote the sale, use or other dealings in this 
 * Software without prior written authorization from the author.
 */

#include "MainWindow.h"
#include <stdlib.h>

/*
 * inits and returns a MainWindow_t handle.
 * If something went wrong returns NULL
 * If logfile is not NULL every write in
 * the output window is also written on the
 * file
 */
MainWindow_t*
InitScreen(const char* logfile)
{
   MainWindow_t *mw = NULL;
   int i;
   int w,h;

   mw = malloc(sizeof(MainWindow_t));
   if(!mw) return NULL;

   /*standard ncurses initialization*/
   initscr();
   keypad(stdscr, TRUE);
   refresh();

   /*finds out the term geometry*/
   w = COLS;
   h = LINES;

   mw->TermHeight = h;
   mw->TermWidth = w;

   /*creates the rubber for input window line*/
   mw->ClearString = malloc(sizeof(char)*w);
   if(!mw->ClearString)
   {
      free(mw);
      endwin();
      return NULL;
   }
   for(i = 0; i<(w-1); ++i) mw->ClearString[i] = ' ';
   mw->ClearString[i] = '\0';

   /*set up the logfile*/
   if(logfile)
   {
      mw->Log = fopen(logfile, "w");
      if(!mw->Log)
      {
	 free(mw);
	 endwin();
	 return NULL;
      }
   }
   else
   {
      mw->Log = NULL;
   }

   /*initialization of the mutex for cursor operations*/
   mw->Mutex = malloc(sizeof(pthread_mutex_t));
   if(!mw->Mutex)
   {
      if(mw->Log) fclose(mw->Log);
      free(mw);
      endwin();
      return NULL;
   }
   pthread_mutex_init(mw->Mutex,NULL);

   /*creates windows*/
   mw->InWin = newwin (1, w-1, h-1, 0);
   mw->OutWin = newwin (h-1, w-1, 0, 0);
   box(mw->OutWin, 0, 0);

   /*sets auto scroll for output*/
   scrollok(mw->OutWin, TRUE);
 
   /*sets the pointer of out to the begin*/
   wmove(mw->OutWin, 1, 0);
   wrefresh(mw->OutWin); 

   /*prints the prompt on input*/
   mvwaddch(mw->InWin, 0, 0, '>');
   wrefresh(mw->InWin);

   return mw;
}
