/* -*- mode: c -*- */
/*
 * Copyright 2005-2006  Francesco Nidito <nids@di.unipi.it>
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation.
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 * Except as contained in this notice, the name of the author shall not be used 
 * in advertising or otherwise to promote the sale, use or other dealings in this 
 * Software without prior written authorization from the author.
 */

#ifndef _MAINWINDOW_H_
#define _MAINWINDOW_H_

#include <curses.h>
#include <pthread.h>

#ifdef __STDC_VERSION__
#  ifndef STDC
#    define STDC
#  endif
#  if __STDC_VERSION__ >= 199901L
#    ifndef STDC99
#      define STDC99
#    endif
#  endif
#endif

#if !defined(STDC) && (defined(__STDC__) || defined(__cplusplus))
#  define STDC
#endif
#if !defined(STDC) && defined(__GNUC__)
#  define STDC
#endif

#ifndef _P
#  ifdef STDC
#    define _P(args)  args
#  else
#    define _P(args)  ()
#  endif
#endif

#ifdef __cplusplus
extern "C" {
#endif

#ifndef _REENTRANT
#  define _REENTRANT
#endif

   typedef struct
   {
	 WINDOW *InWin;
	 WINDOW *OutWin;
	 char* ClearString;
	 int TermWidth;
	 int TermHeight;
	 pthread_mutex_t *Mutex;
	 FILE *Log;
   } MainWindow_t;
   
   MainWindow_t* InitScreen    _P((const char* logfile));
   
   void          ResizeScreen  _P((MainWindow_t *mw));
   
   int           PrintString   _P((MainWindow_t* mw, const char* str));
   int           PrintError    _P((MainWindow_t* mw, const char* str));
   int           PrintMessage  _P((MainWindow_t* mw, const char* str));
   
   int           ReadString    _P((MainWindow_t* mw, char* str, int length));
   
   void          DestroyScreen _P((MainWindow_t* mw));

#ifdef __cplusplus
}
#endif

#endif /*!_MAINWINDOW_H_*/
