/* -*- mode: c -*- */
/*
 * Copyright 2005-2006  Francesco Nidito <nids@di.unipi.it>
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation.
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 * Except as contained in this notice, the name of the author shall not be used 
 * in advertising or otherwise to promote the sale, use or other dealings in this 
 * Software without prior written authorization from the author.
 */

#include "MainWindow.h"

/* 
 * prints str to the output window.
 *
 * returns ERR is something went wrong and OK if 
 * everithing was fine
 */
int
PrintString(MainWindow_t* mw, 
	    const char* str
   )
{
   int r;
   int old_x, old_y;

   if(!mw) return ERR;
   if(!str) return ERR;

   pthread_mutex_lock(mw->Mutex);

   /*save InBox cursor position*/
   getyx(mw->InWin, old_y, old_x);

   /*skip the left border*/
   waddstr(mw->OutWin," ");
   
   /*print the string*/
   r = waddstr(mw->OutWin,str);
   waddch(mw->OutWin,'\n');

   if(mw->Log)
   {
      fprintf(mw->Log,"%s\n",str);
      fflush(mw->Log);
   }

   /*print again the box*/
   box(mw->OutWin, 0, 0);
   wrefresh(mw->OutWin);
   
   /*Put back focus on input bar*/
   wmove(mw->InWin, old_y, old_x);
   wrefresh(mw->InWin);

   pthread_mutex_unlock(mw->Mutex);

   return r;
}

 
