/* -*- mode: c -*- */
/*
 * Copyright 2005-2006  Francesco Nidito <nids@di.unipi.it>
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation.
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 * Except as contained in this notice, the name of the author shall not be used 
 * in advertising or otherwise to promote the sale, use or other dealings in this 
 * Software without prior written authorization from the author.
 */

#include "MainWindow.h"
#include <string.h>
#include <signal.h>
#include <stdlib.h>

MainWindow_t *mw; 

void
SigIntHandler(int segnum)
{
   DestroyScreen(mw);
   _Exit(0);
}

void
ResizeHandler(int segnum)
{
   ResizeScreen(mw);	
}

int
main(int argc, char** argv)
{
   int (*f[3])(MainWindow_t*, const char*) = {PrintString,
					      PrintError, 
					      PrintMessage};
   int i = 0;
   char str[256];

   struct sigaction saWhinch;
   struct sigaction saInt;

   mw = InitScreen("echo_shell.log");

   saWhinch.sa_handler = ResizeHandler;
   sigemptyset(&saWhinch.sa_mask);
   saWhinch.sa_flags = SA_RESTART; 
    
   sigaction(SIGWINCH, &saWhinch, NULL);

   saInt.sa_handler = SigIntHandler;
   sigemptyset(&saInt.sa_mask);
   saInt.sa_flags = SA_RESTART; 
    
   sigaction(SIGINT, &saInt, NULL);

   for(;;)
   {
      int c;
      c = ReadString(mw,str,256);
      
      if(c > 0)
      {
	 if(!strcmp(str,"quit")) break;

	 f[i++](mw, str);
	 i %= 3;
      }
   }

   DestroyScreen(mw);

   return 0;
}
